sound_waveform library

Classes

Amplitude
dBFS amplitude
AnimatedWaveList
A widget that displays an animated list of waveform bars based on a stream of amplitude values.
Waveform

Extensions

AmplitudeHelper on Amplitude

Functions

createRandomAmplitudeStream() Stream<Amplitude>
Creates a stream of random amplitude values.